Bottleneck 1.3.2
================

*Release date: 2020-02-20*

Bug Fixes
~~~~~~~~~
- Explicitly declare numpy version dependency in ``pyproject.toml``
  for Python 3.8, fixing certain cases where ``pip install`` would
  fail. Thanks to ``@goggle``, ``@astrofrog``, and ``@0xb0b`` for
  reporting. (:issue:`277`)

Contributors
~~~~~~~~~~~~

.. contributors:: v1.3.1..v1.3.2
